==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/petitions/lang/petitions_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Вы удалите все подписи. Продолжить ?',
	'aucune_signature' => 'Пока нет ни одной подписи',

	// B
	'bouton_checkbox_envoi_message' => 'возможность отправлять сообщения',
	'bouton_checkbox_indiquer_site' => 'необходимо указать название сайта',
	'bouton_checkbox_signature_unique_email' => 'один email - одна подпись',
	'bouton_checkbox_signature_unique_site' => 'один сайт = одна подпись',

	// F
	'filtre' => 'Фильтр:',
	'form_pet_adresse_site' => 'URL вашего сайта',
	'form_pet_aucune_signature' => 'Не найдено подписей, соответствующих этому коду...',
	'form_pet_confirmation' => 'Пожалуйста, подтвердите вашу подпись:',
	'form_pet_deja_signe' => 'Вы уже оставили подпись под этим текст.',
	'form_pet_envoi_mail_confirmation' => 'Вам было отправлено письмо на e-mail @email@. Что бы подтвердить вашу подпись перейдите по ссылке в письме.',
	'form_pet_mail_confirmation' => 'Добрый день,

Вы решили поддержать материал:
@titre@.

Вы предоставили следующую информацию:
    Имя: @nom_email@
    Сайт: @nom_site@ - @url_site@

Важно!
Чтобы подтвердить свою подпись, перейдите, пожалуйста, по указанному ниже адресу 
(иначе, ваша подпись будет удалена):
    @url@
    @message@

Спасибо за участие!
',
	'form_pet_message_commentaire' => 'Сообщение, комментарий ?',
	'form_pet_nom_site2' => 'Название вашего сайта',
	'form_pet_probleme_liens' => 'Отредактируйте ваше сообщение, удалив из него все ссылки.',
	'form_pet_probleme_technique' => 'Техническая проблема, временно нельзя оставлять подписи.',
	'form_pet_signature_validee' => 'Ваша подпись подтверждена. Спасибо!',
	'form_pet_site_deja_enregistre' => 'Этот сайт уже зарегистрирован',
	'form_pet_url_invalide' => 'Вы указали неправильный URL сайта.',
	'form_pet_votre_email' => 'Ваш e-mail адрес',
	'form_pet_votre_nom' => 'Как вас зовут',
	'form_pet_votre_site' => 'Вы можете указать URL вашего сайта',

	// I
	'icone_relancer_signataire' => 'Повторно связаться с автором',
	'icone_relancer_signataires' => 'Повторно связаться с авторами',
	'icone_suivi_petitions' => 'Управление подписями',
	'icone_supprimer_signature' => 'Удалить подпись',
	'icone_supprimer_signatures' => 'Удалить подписи',
	'icone_valider_signature' => 'Подтвердить подпись',
	'icone_valider_signatures' => 'Подтвердить подписи',
	'info_adresse_email' => 'E-MAIL:',
	'info_fonctionnement_petition' => 'Настройки :',
	'info_signature_supprimee' => 'Подпись удалена',
	'info_signature_supprimee_erreur' => 'Ошибка: данному удалению не соответствует ни одна подпись',
	'info_site_web' => 'ВЕБСАЙТ:',
	'info_texte_message' => 'Текст сообщения или комментария :',

	// L
	'lien_reponse_article' => 'Оставить комментарий',

	// N
	'nombre_signatures' => '@nb@ подписей',

	// S
	'sans_nom' => 'Анонимус',
	'signatures_article' => 'Подписи под статьей :',
	'signatures_aucune' => 'Отсутствует',
	'signatures_meme_auteur' => 'Подписи этого же автора',
	'signatures_meme_site' => 'Подписи с такого же сайта',
	'signatures_poubelle' => 'Удаленные',
	'signatures_prop' => 'Ожидают',
	'signatures_publie' => 'Подтвержденные',
	'signatures_recherche_label' => 'Найти подпись :',
	'signatures_selection' => 'Sélectionner les signatures :', # NEW
	'signatures_toutes' => 'Все',
	'statut_poubelle' => 'Удаленные',
	'statut_prop' => 'Ожидают подтверждения',
	'statut_publie' => 'Подтвержденные',

	// T
	'texte_descriptif_petition' => 'Описание',
	'titre_page_controle_petition' => 'Отслеживание подписей',
	'titre_petition' => 'Подпись',
	'titre_petitions' => 'Подписи',
	'titre_selection_action' => 'Выбор',
	'titre_signatures_attente' => 'Подписи, ожидающие подтверждения',
	'titre_signatures_publie' => 'Подтвержденные подписи',
	'titre_suivi_petition' => 'Отслеживание подписей',
	'tout_voir' => 'Показать все подписи',

	// U
	'une_signature' => '1 подпись',

	// V
	'voir_signatures_objet' => 'Показать подписи'
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/petitions/lang/petitions_ru.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=ru
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Вы удалите все подписи. Продолжить ?',
	'aucune_signature' => 'Пока нет ни одной подписи',

	// B
	'bouton_checkbox_envoi_message' => 'возможность отправлять сообщения',
	'bouton_checkbox_indiquer_site' => 'необходимо указать название сайта',
	'bouton_checkbox_signature_unique_email' => 'один email - одна подпись',
	'bouton_checkbox_signature_unique_site' => 'один сайт = одна подпись',
	'bouton_radio_activer_petition' => 'Включить комментарии',
	'bouton_radio_pas_petition' => 'Отключить комментарии',
	'bouton_radio_petition_activee' => 'Включить комментарии',
	'bouton_radio_supprimer_petition' => 'Удалить комментарии',

	// F
	'filtre' => 'Фильтр:',
	'form_pet_adresse_site' => 'URL вашего сайта',
	'form_pet_aucune_signature' => 'Не найдено подписей, соответствующих этому коду...',
	'form_pet_confirmation' => 'Пожалуйста, подтвердите вашу подпись:',
	'form_pet_deja_signe' => 'Вы уже оставили подпись под этим текст.',
	'form_pet_envoi_mail_confirmation' => 'Вам было отправлено письмо на e-mail @email@. Что бы подтвердить вашу подпись перейдите по ссылке в письме.',
	'form_pet_mail_confirmation' => 'Добрый день,

Вы решили поддержать материал:
@titre@.

Вы предоставили следующую информацию:
    Имя: @nom_email@
    Сайт: @nom_site@ - @url_site@

Важно!
Чтобы подтвердить свою подпись, перейдите, пожалуйста, по указанному ниже адресу 
(иначе, ваша подпись будет удалена):
    @url@
    @message@

Спасибо за участие!
',
	'form_pet_message_commentaire' => 'Сообщение, комментарий ?',
	'form_pet_nom_site2' => 'Название вашего сайта',
	'form_pet_probleme_liens' => 'Отредактируйте ваше сообщение, удалив из него все ссылки.',
	'form_pet_probleme_technique' => 'Техническая проблема, временно нельзя оставлять подписи.',
	'form_pet_signature_validee' => 'Ваша подпись подтверждена. Спасибо!',
	'form_pet_site_deja_enregistre' => 'Этот сайт уже зарегистрирован',
	'form_pet_url_invalide' => 'Вы указали неправильный URL сайта.',
	'form_pet_votre_email' => 'Ваш e-mail адрес',
	'form_pet_votre_nom' => 'Как вас зовут',
	'form_pet_votre_site' => 'Вы можете указать URL вашего сайта',

	// I
	'icone_relancer_signataire' => 'Повторно связаться с автором',
	'icone_relancer_signataires' => 'Повторно связаться с авторами',
	'icone_suivi_petitions' => 'Управление подписями',
	'icone_supprimer_signature' => 'Удалить подпись',
	'icone_supprimer_signatures' => 'Удалить подписи',
	'icone_valider_signature' => 'Подтвердить подпись',
	'icone_valider_signatures' => 'Подтвердить подписи',
	'info_adresse_email' => 'E-MAIL:',
	'info_fonctionnement_petition' => 'Настройки :',
	'info_signature_supprimee' => 'Подпись удалена',
	'info_signature_supprimee_erreur' => 'Ошибка: данному удалению не соответствует ни одна подпись',
	'info_site_web' => 'ВЕБСАЙТ:',
	'info_texte_message' => 'Текст сообщения или комментария :',

	// L
	'lien_reponse_article' => 'Оставить комментарий',

	// N
	'nombre_signatures' => '@nb@ подписей',

	// S
	'sans_nom' => 'Анонимус',
	'signatures_article' => 'Подписи под статьей :',
	'signatures_aucune' => 'Отсутствует',
	'signatures_meme_auteur' => 'Подписи этого же автора',
	'signatures_meme_site' => 'Подписи с такого же сайта',
	'signatures_poubelle' => 'Удаленные',
	'signatures_prop' => 'Ожидают',
	'signatures_publie' => 'Подтвержденные',
	'signatures_recherche_label' => 'Найти подпись :',
	'signatures_selection' => 'Выбор подписи :',
	'signatures_toutes' => 'Все',
	'statut_poubelle' => 'Удаленные',
	'statut_prop' => 'Ожидают подтверждения',
	'statut_publie' => 'Подтвержденные',

	// T
	'texte_descriptif_petition' => 'Описание',
	'titre_page_controle_petition' => 'Отслеживание подписей',
	'titre_petition' => 'Подпись',
	'titre_petitions' => 'Подписи',
	'titre_selection_action' => 'Выбор',
	'titre_signatures_attente' => 'Подписи, ожидающие подтверждения',
	'titre_signatures_publie' => 'Подтвержденные подписи',
	'titre_suivi_petition' => 'Отслеживание подписей',
	'tout_voir' => 'Показать все подписи',

	// U
	'une_signature' => '1 подпись',

	// V
	'voir_signatures_objet' => 'Показать подписи'
);

?>
